@@ -7,7 +7,7 @@ Attean::API::Model - RDF Model
 
 =head1 VERSION
 
-This document describes Attean::API::Model version 0.017
+This document describes Attean::API::Model version 0.020
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,13 @@ L<Attean::API::QuadIterator>.
 Returns the number of quads in the model matching the supplied pattern
 (using the same matching semantics as C<< get_quads >>).
 
+=item C<< count_quads_estimate( $subject, $predicate, $object, $graph ) >>
+
+Returns an estimate of the number of quads in the model matching the supplied
+pattern (using the same matching semantics as C<< get_quads >>). This estimate
+is guaranteed to non-zero if the count returned from an equivalent call to
+`count_quads` would return a non-zero result.
+
 =item C<< get_graphs >>
 
 Returns an L<Attean::API::Iterator> of distinct L<Attean::API::Term> objects
@@ -115,14 +122,14 @@ subjects and objects present in the specified C<< $graph >>.
 
 use Attean::API::Binding;
 
-package Attean::API::Model 0.017 {
-	use Moo::Role;
+package Attean::API::Model 0.020 {
 	use Sub::Install;
 	use Sub::Util qw(set_subname);
 	use URI::Namespace;
 	use Scalar::Util qw(blessed);
 	use List::MoreUtils qw(uniq);
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	# get_quads($s, $p, $o, $g)
 	# or:
@@ -151,6 +158,7 @@ package Attean::API::Model 0.017 {
 	}
 	
 	requires 'count_quads';
+	requires 'count_quads_estimate';
 	requires 'get_graphs';
 	
 	sub get_list {
@@ -236,13 +244,13 @@ package Attean::API::Model 0.017 {
 }
 
 
-package Attean::API::MutableModel 0.017 {
-	use Moo::Role;
+package Attean::API::MutableModel 0.020 {
 	use Attean::RDF;
 	use LWP::UserAgent;
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
-	use namespace::clean;
+
+	use Moo::Role;
 	
 	requires 'add_quad';
 	requires 'remove_quad';
@@ -328,21 +336,21 @@ package Attean::API::MutableModel 0.017 {
 }
 
 
-package Attean::API::ETagCacheableModel 0.017 {
+package Attean::API::ETagCacheableModel 0.020 {
 	use Moo::Role;
 	
 	requires 'etag_value_for_quads';
 }
 
 
-package Attean::API::TimeCacheableModel 0.017 {
+package Attean::API::TimeCacheableModel 0.020 {
 	use Moo::Role;
 	
 	requires 'mtime_for_quads';
 }
 
 
-package Attean::API::BulkUpdatableModel 0.017 {
+package Attean::API::BulkUpdatableModel 0.020 {
 	use Moo::Role;
 	
 	with 'Attean::API::MutableModel';
@@ -359,7 +367,7 @@ package Attean::API::BulkUpdatableModel 0.017 {
 	};
 
 	# End bulk updates the moment a read operation is performed...
-	before [qw(get_quads get_bindings count_quads get_graphs subject predicate object graph)] => sub {
+	before [qw(get_quads get_bindings count_quads count_quads_estimate get_graphs subject predicate object graph)] => sub {
 		my $self	= shift;
 		$self->end_bulk_updates();
 	};
@@ -379,7 +387,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -387,7 +395,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
