@@ -7,7 +7,7 @@ Attean::API::Query - Utility package defining query-related roles
 
 =head1 VERSION
 
-This document describes Attean::API::Query version 0.016
+This document describes Attean::API::Query version 0.020
 
 =head1 SYNOPSIS
 
@@ -24,11 +24,11 @@ This is a utility package for defining query-related roles:
 
 =cut
 
-package Attean::API::DirectedAcyclicGraph 0.016 {
-	use Moo::Role;
+package Attean::API::DirectedAcyclicGraph 0.020 {
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(ArrayRef ConsumerOf);
-	use namespace::clean;
+
+	use Moo::Role;
 
 # =item C<< children >>
 # 
@@ -149,15 +149,15 @@ package Attean::API::DirectedAcyclicGraph 0.016 {
 	}
 }
 
-package Attean::API::SPARQLSerializable 0.016 {
+package Attean::API::SPARQLSerializable 0.020 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
-	use Moo::Role;
 	use Encode qw(decode_utf8);
 	use Attean::API::Iterator;
 	use Attean::API::Serializer;
 	use AtteanX::Serializer::SPARQL;
-	use namespace::clean;
+
+	use Moo::Role;
 
 	requires 'sparql_tokens';
 	
@@ -402,7 +402,7 @@ package Attean::API::SPARQLSerializable 0.016 {
 	}
 }
 
-package Attean::API::SPARQLQuerySerializable 0.016 {
+package Attean::API::SPARQLQuerySerializable 0.020 {
 	use Moo::Role;
 	use namespace::clean;
 	with 'Attean::API::SPARQLSerializable';
@@ -417,7 +417,7 @@ package Attean::API::SPARQLQuerySerializable 0.016 {
 
 =cut
 
-package Attean::API::Algebra 0.016 {
+package Attean::API::Algebra 0.020 {
 	use Moo::Role;
 
 	with 'Attean::API::SPARQLSerializable';
@@ -483,7 +483,7 @@ package Attean::API::Algebra 0.016 {
 				my $children	= $self->children;
 				my $size	= scalar(@$children);
 				unless ($size == $arity) {
-					die "${name} algebra construction with bad number of children (expected $arity, but got $size)";
+					Carp::confess "${name} algebra construction with bad number of children (expected $arity, but got $size)";
 				}
 			}
 		}
@@ -494,7 +494,7 @@ package Attean::API::Algebra 0.016 {
 
 =cut
 
-package Attean::API::QueryTree 0.016 {
+package Attean::API::QueryTree 0.020 {
 	use Moo::Role;
 	with 'Attean::API::DirectedAcyclicGraph';
 }
@@ -503,7 +503,7 @@ package Attean::API::QueryTree 0.016 {
 
 =cut
 
-package Attean::API::NullaryQueryTree 0.016 {
+package Attean::API::NullaryQueryTree 0.020 {
 	use Moo::Role;
 	sub arity { return 0 }
 	with 'Attean::API::QueryTree';
@@ -513,7 +513,7 @@ package Attean::API::NullaryQueryTree 0.016 {
 
 =cut
 
-package Attean::API::UnaryQueryTree 0.016 {
+package Attean::API::UnaryQueryTree 0.020 {
 	use Moo::Role;
 	sub arity { return 1 }
 	with 'Attean::API::QueryTree';
@@ -528,7 +528,7 @@ package Attean::API::UnaryQueryTree 0.016 {
 
 =cut
 
-package Attean::API::BinaryQueryTree 0.016 {
+package Attean::API::BinaryQueryTree 0.020 {
 	use Moo::Role;
 	sub arity { return 2 }
 	with 'Attean::API::QueryTree';
@@ -538,7 +538,7 @@ package Attean::API::BinaryQueryTree 0.016 {
 
 =cut
 
-package Attean::API::PropertyPath 0.016 {
+package Attean::API::PropertyPath 0.020 {
 	use Moo::Role;
 	with 'Attean::API::QueryTree';
 	requires 'as_string';
@@ -549,10 +549,10 @@ package Attean::API::PropertyPath 0.016 {
 
 =cut
 
-package Attean::API::UnaryPropertyPath 0.016 {
-	use Moo::Role;
+package Attean::API::UnaryPropertyPath 0.020 {
 	use Types::Standard qw(ConsumerOf);
-	use namespace::clean;
+
+	use Moo::Role;
 
 	sub arity { return 1 }
 # 	has 'path' => (is => 'ro', isa => ConsumerOf['Attean::API::PropertyPath'], required => 1);
@@ -579,10 +579,10 @@ package Attean::API::UnaryPropertyPath 0.016 {
 
 =cut
 
-package Attean::API::NaryPropertyPath 0.016 {
-	use Moo::Role;
+package Attean::API::NaryPropertyPath 0.020 {
 	use Types::Standard qw(ArrayRef ConsumerOf);
-	use namespace::clean;
+
+	use Moo::Role;
 
 # 	has 'children' => (is => 'ro', isa => ArrayRef[ConsumerOf['Attean::API::PropertyPath']], required => 1);
 	requires 'separator';
@@ -606,7 +606,7 @@ package Attean::API::NaryPropertyPath 0.016 {
 
 =cut
 
-package Attean::API::UnionScopeVariables 0.016 {
+package Attean::API::UnionScopeVariables 0.020 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -622,7 +622,7 @@ package Attean::API::UnionScopeVariables 0.016 {
 
 =cut
 
-package Attean::API::IntersectionScopeVariables 0.016 {
+package Attean::API::IntersectionScopeVariables 0.020 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -648,7 +648,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -656,7 +656,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
