@@ -7,7 +7,7 @@ Attean::API::Store - Triple/quad store role
 
 =head1 VERSION
 
-This document describes Attean::Store version 0.016
+This document describes Attean::Store version 0.020
 
 =head1 DESCRIPTION
 
@@ -35,15 +35,15 @@ The Attean::Store role is an empty role that more specialized roles conform to:
 
 =cut
 
-package Attean::API::Store 0.016 {
+package Attean::API::Store 0.020 {
 	use Moo::Role;
 }
 
-package Attean::API::TripleStore 0.016 {
-	use Moo::Role;
+package Attean::API::TripleStore 0.020 {
 	use Scalar::Util qw(blessed);
-	use namespace::clean;
-	
+
+	use Moo::Role;
+
 	with 'Attean::API::Store';
 
 	requires 'get_triples';
@@ -74,9 +74,15 @@ package Attean::API::TripleStore 0.016 {
 		my $self	= shift;
 		return $self->count_triples();
 	}
+
+	sub holds {
+	  my $self = shift;
+	  return ($self->count_triples_estimate(@_) > 0)
+	}
+
 }
 
-package Attean::API::MutableTripleStore 0.016 {
+package Attean::API::MutableTripleStore 0.020 {
 	use Moo::Role;
 	with 'Attean::API::TripleStore';
 	
@@ -92,25 +98,25 @@ package Attean::API::MutableTripleStore 0.016 {
 	};
 }
 
-package Attean::API::ETagCacheableTripleStore 0.016 {
+package Attean::API::ETagCacheableTripleStore 0.020 {
 	use Moo::Role;
 	with 'Attean::API::TripleStore';
 	
 	requires 'etag_value_for_triples';
 }
 
-package Attean::API::TimeCacheableTripleStore 0.016 {
+package Attean::API::TimeCacheableTripleStore 0.020 {
 	use Moo::Role;
 	with 'Attean::API::TripleStore';
 	
 	requires 'mtime_for_triples';
 }
 
-package Attean::API::QuadStore 0.016 {
-	use Moo::Role;
+package Attean::API::QuadStore 0.020 {
 	use Scalar::Util qw(blessed);
-	use namespace::clean;
-	
+
+	use Moo::Role;
+
 	with 'Attean::API::Store';
 
 	requires 'get_quads';
@@ -136,7 +142,12 @@ package Attean::API::QuadStore 0.016 {
 		my $self	= shift;
 		return $self->count_quads(@_);
 	}
-	
+
+	sub holds {
+	  my $self = shift;
+	  return ($self->count_quads_estimate(@_) > 0)
+	}
+
 	sub get_graphs {
 		my $self	= shift;
 		my $iter	= $self->get_quads(@_);
@@ -154,7 +165,7 @@ package Attean::API::QuadStore 0.016 {
 	}
 }
 
-package Attean::API::MutableQuadStore 0.016 {
+package Attean::API::MutableQuadStore 0.020 {
 	use Moo::Role;
 	use Type::Tiny::Role;
 	with 'Attean::API::QuadStore';
@@ -185,7 +196,7 @@ package Attean::API::MutableQuadStore 0.016 {
 	}
 }
 
-package Attean::API::ETagCacheableQuadStore 0.016 {
+package Attean::API::ETagCacheableQuadStore 0.020 {
 	use Moo::Role;
 
 	with 'Attean::API::QuadStore';
@@ -193,7 +204,7 @@ package Attean::API::ETagCacheableQuadStore 0.016 {
 	requires 'etag_value_for_quads';
 }
 
-package Attean::API::TimeCacheableQuadStore 0.016 {
+package Attean::API::TimeCacheableQuadStore 0.020 {
 	use Moo::Role;
 
 	with 'Attean::API::QuadStore';
@@ -201,7 +212,7 @@ package Attean::API::TimeCacheableQuadStore 0.016 {
 	requires 'mtime_for_quads';
 }
 
-package Attean::API::BulkUpdatableStore 0.016 {
+package Attean::API::BulkUpdatableStore 0.020 {
 	use Moo::Role;
 	
 	requires 'begin_bulk_updates';
@@ -219,7 +230,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
@@ -227,7 +238,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
