@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLJSON - SPARQL Results JSON Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLJSON version 0.034
+This document describes AtteanX::Serializer::SPARQLJSON version 0.020
 
 =head1 SYNOPSIS
 
@@ -22,8 +22,6 @@ This document describes AtteanX::Serializer::SPARQLJSON version 0.034
 
 =item C<< canonical_media_type >>
 
-=item C<< file_extensions >>
-
 =back
 
 =head1 METHODS
@@ -35,7 +33,7 @@ This document describes AtteanX::Serializer::SPARQLJSON version 0.034
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLJSON 0.034 {
+package AtteanX::Serializer::SPARQLJSON 0.020 {
 	use Moo;
 	use Types::Standard qw(Str);
 	use Encode qw(encode);
@@ -56,14 +54,6 @@ Returns a list of media types that identify the format produced by this serializ
 		return [qw(application/sparql-results+json)];
 	}
 
-=item C<< file_extensions >>
-
-Returns a list of file extensions associated with the serialized format.
-
-=cut
-
-	sub file_extensions { return [qw(srj json)] };
-
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
 Serializes the L<Attean::API::Binding> objects from C<< $iterator >> to the
@@ -153,7 +143,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2022 Gregory Todd Williams. This
+Copyright (c) 2014--2018 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
